//
//  XMLAppDelegate.m
//  XML
//
//  Created by Arman Fahmi on 2014.05.26..

#import "XMLAppDelegate.h"
#import "RootViewController.h"
#import "XMLParser.h"
#import <UIKit/UIKit.h>
#import "Book.h"

@implementation XMLAppDelegate

@synthesize window;
@synthesize navigationController, books;

// kezdo muveletek az alkalmazas inditasakor
- (void)applicationDidFinishLaunching:(UIApplication *)application {    
	// Books.xml betoltese resource-bol
    NSString *xmlPath = [[NSBundle mainBundle] pathForResource:@"books" ofType:@"xml"];
	NSData *xmlData = [NSData dataWithContentsOfFile:xmlPath];
	// NSXMLparser inicializalasa
	NSXMLParser *xmlParser = [[NSXMLParser alloc] initWithData:xmlData];	
	
	// a delegalt inicializalasa
	XMLParser *parser = [[XMLParser alloc] initXMLParser];
	
	// delegalt beallitasa
	[xmlParser setDelegate:parser];

	// parseolas
	BOOL success = [xmlParser parse];
	// hiba volt a parseolas kozben?
	if(!success)
	{
		// MessageBox-al jelzem a hibat, es kilepek
		[self showMsg:@"Hiba tortent az XML parse kozben!"];	
		return;
	}
	NSLog(@"parse sikeres volt!");	
	[self setExpires]; // konyvek lejaratanak ellenorzese, es a local notification-k beallitasa
	// table view hozzaadasa a foablakhoz
	[window addSubview:[navigationController view]];
	[window makeKeyAndVisible];
}

// megjeleniti a megadott uzenetet
- (void)showMsg:(NSString*)msg
{
	UIAlertView *alert = [[UIAlertView alloc] initWithTitle:nil 
													message:msg
												   delegate:self 
										  cancelButtonTitle:@"OK" 
										  otherButtonTitles:nil];
	[alert show];	
}

// letrehozza az ertesiteseket a kolcsonzesi ido lejaratarol, es ertesit rogton a lejart kolcsonzesi hataridokrol.
- (void) setExpires {
	[[UIApplication sharedApplication] cancelAllLocalNotifications];
	// vegig megy a beolvasott konyveken
	for (Book* book in books) {		
		NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
		// date formatter letrehozasa a string -> date konverziohoz, ha a DateFormatter string nem egyezik az XML-ben 
		// levo date string formatumaval akkor nil objektumot kapunk!
		[dateFormatter setDateFormat:@"yyyy.MM.dd"];
		//[dateFormatter setTimeZone:[NSTimeZone timeZoneWithName:@"Europe/Budapest"]];
		NSDate *dateFromString = [[NSDate alloc] init];
		// \n\r karakterek torlese a datum stringbol
		book.expiration = [book.expiration stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
		// datumma konvertalas
		dateFromString = [dateFormatter dateFromString:book.expiration];
		// konverzios hiba volt?
		if (dateFromString == nil)
		{
			[self showMsg:[NSString stringWithFormat:@"Hiba tortent a %@ datum konvertalasakor.", book.expiration]];
			continue;
		}
		localNotification.timeZone = [NSTimeZone timeZoneWithName:@"Europe/Budapest"];
		// lejart a kolcsonzesi ido?
		if ([self isExpired:dateFromString])
		{
			// ertesitem a felhasznalot
			[self showMsg:[NSString stringWithFormat:@"A %@ könyv %@-n már lejárt!", book.title, book.expiration]];
		}
		else { // kesobb fog lejarni, letrehozom a lejarati ido - 1 nap-ra az ertesitest
			UILocalNotification* localNotification = [[UILocalNotification alloc] init]; 		
			dateFromString = [dateFromString dateByAddingTimeInterval:-1*24*60*60];
			localNotification.fireDate = dateFromString;
			localNotification.alertBody = [NSString stringWithFormat:@"A %s könyv holnap lejár!", book.title];
			[[UIApplication sharedApplication] scheduleLocalNotification:localNotification];
			[localNotification release];
		}
		[dateFormatter release];
	}
	// letrehozott ertesitesek kiloggolasa
	[self logNotifications];
}

// kolcsonzesit datum lejart?
- (bool) isExpired:(NSDate*)_date {
	return [[NSDate date] compare:_date] != NSOrderedAscending;
}

// letrehozott ertesitesek kiloggolasa
- (void)logNotifications
{
	NSLog(@"local notifications created: ");
	NSArray *notifications = [[UIApplication sharedApplication] scheduledLocalNotifications];
	for (int i = 0;i<[notifications count];i++) {
		NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
		
		NSLog(@"firedate is: %@", [[notifications objectAtIndex:i] fireDate]);
	}
}

- (void)applicationWillTerminate:(UIApplication *)application {
	// Save data if appropriate
}


- (void)dealloc {
	[books release];
	[navigationController release];
	[window release];
	[super dealloc];
}

@end
